<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="si">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>එකතු කිරීම්</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
        <source>Advanced Settings</source>
        <translation>උසස් සැකසුම්</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>&quot;උසස් සැකසුම්&quot; පද්ධති සැකසුම් භාවිතා කරන ආදාන ක්‍රමය සඳහා පමණයි වලංගු වේ. ආදාන ක්‍රමයට තමන්ගේම සැකසුම් තිබේ නම්, ඒවා ප්‍රමුඛ වේ.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
        <source>Global Config</source>
        <translation>ගෝලීය වින්‍යාසය</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
        <source>Add-ons</source>
        <translation>එකතු කිරීම්</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
        <source>Keyboard layout</source>
        <translation>යතුරුපුවරු පිරිසැලසුම</translation>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="151"/>
        <source>Please enter a new shortcut</source>
        <translation>කරුණාකර නව කෙටිමගක් ඇතුළත් කරන්න</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>ඉහළට ගන්න</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>පහළට ගන්න</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>සැකසුම්</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>ඉවත් කරන්න</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>ආදාන ක්‍රමය එකතු කරන්න</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>සොයන්න</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>App Store හි තවත් සොයන්න</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>එකතු කරන්න</translation>
    </message>
</context>
<context>
    <name>KeyboardLayout</name>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>යතුරුපුවරු පිරිසැලසුම</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>done</source>
        <translation>අවසන්</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>edit</source>
        <translation>සංස්කරණය</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>යතුරුපුවරු පිරිසැලසුම එකතු කරන විට හෝ මාරු කරන විට ක්‍රියා කරන බව සහතික කිරීම සඳහා &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;ආදාන ක්‍රම කළමනාකරණය&lt;/a&gt; හි අදාළ ආදාන ක්‍රමය එකතු කරන්න.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="142"/>
        <source>Add new keyboard layout...</source>
        <translation>නව යතුරුපුවරු පිරිසැලසුම එකතු කරන්න...</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutModule</name>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>යතුරුපුවරු පිරිසැලසුම</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>done</source>
        <translation>අවසන්</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>edit</source>
        <translation>සංස්කරණය</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>යතුරුපුවරු පිරිසැලසුම එකතු කරන විට හෝ මාරු කරන විට ක්‍රියා කරන බව සහතික කිරීම සඳහා &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;ආදාන ක්‍රම කළමනාකරණය&lt;/a&gt; හි අදාළ ආදාන ක්‍රමය එකතු කරන්න.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
        <source>Add new keyboard layout...</source>
        <translation>නව යතුරුපුවරු පිරිසැලසුම එකතු කරන්න...</translation>
    </message>
</context>
<context>
    <name>LayoutsChooser</name>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="30"/>
        <source>Add new keyboard layout</source>
        <translation>නව යතුරුපුවරු පිරිසැලසුම එකතු කරන්න</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="38"/>
        <source>Search</source>
        <translation>සොයන්න</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="67"/>
        <source>Current language keyboard layouts</source>
        <translation>වත්මන් භාෂාවේ යතුරුපුවරු පිරිසැලසුම්</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="90"/>
        <source>Cancel</source>
            <translation>අවලංගු කරන්න</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="97"/>
        <source>Add</source>
        <translation>එකතු කරන්න</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ආදාන ක්‍රම කළමනාකරණය</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>ආදාන ක්‍රමය එකතු කරන්න</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="12"/>
        <location filename="../qml/ShortcutsModule.qml" line="14"/>
        <location filename="../qml/ShortcutsModule.qml" line="151"/>
        <location filename="../qml/ShortcutsModule.qml" line="152"/>
        <source>None</source>
        <translation>කිසිවක් නැත</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="119"/>
        <source>Shortcuts</source>
        <translation>කෙටිමග</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="134"/>
        <source>Restore Defaults</source>
        <translation>පෙරනිමි ප්‍රතිෂ්ඨාපනය කරන්න</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="200"/>
        <source>Scroll between input methods</source>
        <translation>ආදාන ක්‍රම අතර අනුචලනය</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="230"/>
        <source>Turn on or off input methods</source>
        <translation>ආදාන ක්‍රම සක්‍රිය හෝ අක්‍රිය කරන්න</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="273"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>එය වර්තමානයේ භාවිතා වන ආදාන ක්‍රමය සක්‍රිය හෝ අක්‍රිය කරයි. කිසිදු ආදාන ක්‍රමයක් භාවිතා නොවන්නේ නම් හෝ පළමු ආදාන ක්‍රමය යතුරුපුවරුව නොවේ නම්, එය පළමු ආදාන ක්‍රමය සහ වර්තමානයේ භාවිතා වන යතුරුපුවරුව/ආදාන ක්‍රමය අතර මාරු වේ.</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::dialectNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
        <source>Traditional Chinese (Chinese Hong Kong)</source>
        <translation>සම්ප්‍රදායික චීන (චීන හොංකොං)</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
        <source>Traditional Chinese (Chinese Taiwan)</source>
        <translation>සම්ප්‍රදායික චීන (චීන තායිවානය)</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::regionNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
        <source>Taiwan China</source>
        <translation>තායිවානය චීනය</translation>
    </message>
</context>
<context>
    <name>dccV25::KeyboardController</name>
    <message>
        <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
        <source>This shortcut conflicts with [%1]</source>
            <translation>මෙම කෙටිමග [%1] සමඟ ගැටේ</translation>
    </message>
</context>
<context>
    <name>dccV25::ShortcutModel</name>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="248"/>
        <source>System</source>
        <translation>පද්ධතිය</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="253"/>
        <source>Window</source>
        <translation>කවුළුව</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="258"/>
        <source>Workspace</source>
        <translation>වැඩකරන ස්ථානය</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="263"/>
        <source>AssistiveTools</source>
        <translation>සහායක මෙවලම්</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="268"/>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="339"/>
        <source>Custom</source>
        <translation>අභිරුචි</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="394"/>
        <source>None</source>
        <translation>කිසිවක් නැත</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ආදාන ක්‍රම</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ආදාන ක්‍රම කළමනාකරණය, ආදාන ක්‍රම කෙටිමග, උසස් සැකසුම්</translation>
    </message>
</context>
</TS>